@@ -38,7 +38,7 @@ class DBConnect():
         else:
             return False
 
-    def update_docu(self, find_docu: dict, modify_docu: dict, many=False: bool) -> bool:
+    def update_docu(self, find_docu: dict, modify_docu: dict, many=False) -> bool:
         try:
             if many:
                 self.mongo_collection.update_many(find_docu, modify_docu)
