@@ -1,7 +1,13 @@
+import logging
 from datetime import datetime, timedelta
 
+logging.basicConfig(
+    level=logging.WARNING,
+    format='[%(asctime)s] [%(levelname)s] %(message)s'
+)
 
-def handle_date(date: str, date_type='start'):
+
+def handle_date(date: str, date_type='start') -> datetime.datetime:
     try:
         if len(date) == 0:
             date_data = None
